==> sharkmon-1.2.8.tgz: package/Readme.md <==
# Sharkmon
- [![Travis CI](https://api.travis-ci.org/Sharkbyteprojects/SharkMon.svg?branch=master)](https://travis-ci.org/github/Sharkbyteprojects/SharkMon)
- [DEMO](https://glitch.com/~sharkmon-demo)

## How To:
### Start
- Install [`Node.JS`](https://nodejs.org/) and [`NPM`](https://www.npmjs.com/)
- Run `npm init`
- Create `index.js`
- Run `npm install sharkmon`
- Write `require("sharkmon");` 
to the `index.js`
- Run your `index.js`
### View
- Open [`http://localhost:8080`](http://localhost:8080)
in your Browser

## Dependencies
name 		| Version
----------- | ---------
express 	| ^4.17.1
rxjs 		| ^6.5.5
socket.io 	| ^2.3.0

## Repos
- [GITLAB](https://gitlab.com/Sharkbyteprojects/SharkMon)
- [GitHUB](https://github.com/Sharkbyteprojects/SharkMon)

## USED ICONS
### Created by Sharkbyteprojects
- ![](https://raw.githubusercontent.com/Sharkbyteprojects/SharkMon/master/static/icons/core.svg)
- ![](https://raw.githubusercontent.com/Sharkbyteprojects/SharkMon/master/static/icons/ram.svg)
- ![](https://raw.githubusercontent.com/Sharkbyteprojects/SharkMon/master/static/icons/os/osapple.svg)
- ![](https://raw.githubusercontent.com/Sharkbyteprojects/SharkMon/master/static/icons/os/oslinux.svg)
- ![](https://raw.githubusercontent.com/Sharkbyteprojects/SharkMon/master/static/icons/os/osms.svg)
- ![](https://raw.githubusercontent.com/Sharkbyteprojects/SharkMon/master/static/icons/os/osunkown.svg)
- ![](https://raw.githubusercontent.com/Sharkbyteprojects/SharkMon/master/static/icons/network.svg)

==> sharkmon-2.3.9.tgz: package/Readme.md <==
# Sharkmon
- [![Travis CI](https://api.travis-ci.org/Sharkbyteprojects/SharkMon.svg?branch=master)](https://travis-ci.org/github/Sharkbyteprojects/SharkMon)
- [DEMO](https://glitch.com/~sharkmon-demo)

## How To:
### Start
- Install [`Node.JS`](https://nodejs.org/) and [`NPM`](https://www.npmjs.com/)
- Run `npx sharkmon`
### View
- Open [`http://localhost:8080`](http://localhost:8080)
in your Browser

## Dependencies
name 		                 | Version
---------------------------- | ---------
express 	                 | ^4.17.1
rxjs 		                 | ^6.5.5
socket.io 	                 | ^2.3.0
win-drive-internal-sharkmon  | ^1.0.0

## Repos
- [GITLAB](https://gitlab.com/Sharkbyteprojects/SharkMon)
- [GitHUB](https://github.com/Sharkbyteprojects/SharkMon)

## USED ICONS
### Created by Sharkbyteprojects
- ![](https://raw.githubusercontent.com/Sharkbyteprojects/SharkMon/master/static/icons/core.svg)
- ![](https://raw.githubusercontent.com/Sharkbyteprojects/SharkMon/master/static/icons/ram.svg)
- ![](https://raw.githubusercontent.com/Sharkbyteprojects/SharkMon/master/static/icons/os/osapple.svg)
- ![](https://raw.githubusercontent.com/Sharkbyteprojects/SharkMon/master/static/icons/os/oslinux.svg)
- ![](https://raw.githubusercontent.com/Sharkbyteprojects/SharkMon/master/static/icons/os/osms.svg)
- ![](https://raw.githubusercontent.com/Sharkbyteprojects/SharkMon/master/static/icons/os/osunkown.svg)
- ![](https://raw.githubusercontent.com/Sharkbyteprojects/SharkMon/master/static/icons/network.svg)
